@@ -328,6 +328,9 @@ mod tests {
         }, CurrencyTestCase {
             name: "HKD", // 344 - Гонконгский доллар
             rate: dec!(9.53013),
+        }, CurrencyTestCase {
+            name: "AUD", // 036 - Австралийский доллар
+            rate: dec!(56.9065),
         }] {
             let local_amount = crate::currency::round(amount * currency.rate);
 
@@ -345,7 +348,6 @@ mod tests {
         compare_to(&statement, &data);
     }
 
-    // FIXME(konishchev): Generate
     #[test]
     fn parse_real() {
         test_parsing(&get_path("statement"));
@@ -361,10 +363,16 @@ mod tests {
         statement
     }
 
-    fn compare_to(statement: &TaxStatement, data: &str) {
+    fn compare_to(statement: &TaxStatement, mut data: &str) {
         let temp_file = NamedTempFile::new().unwrap();
         let path = temp_file.path().to_str().unwrap();
 
+        // Декларация program sometimes writes zero bytes to the tail of the file. This behaviour
+        // varies from version to version, seems to have no meaning and looks like a serialization
+        // bug. So just ignore it.
+        data = data.trim_end_matches('\0');
+        assert!(!data.is_empty());
+
         TaxStatementWriter::write(statement, path).unwrap();
         assert_eq!(&get_contents(path), data);
     }
